==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtsubstrHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "cutting substring as new field"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "attribute"
#define FLDC "an attribute from which substring is extracted (you cannot specify more than one attribute)"
#define FLDF ""

/*-R*/
#define RNGT "range list"
#define RNGC "specify the start and the last position of the specified attribute to be extracted"

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " For an attribute specified by -f, this command extracts a substring of the attribute specified by  -R, and outputs it 
as a new attribute (or replaces the original attribute value with it)."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  xtsubstr -fdate:year -R 1_4 -i dat.xt -o rsl.xt\n\
  xtsubstr -fdate:year_dairy -R 1_4,7_8 -i dat.xt -o rsl.xt\n\
  xtsubstr -fdate:year -R 1_4 -A -i dat.xt -o rsl.xt\n\
  xtsubstr -fdate:month_dairy -R 5_MAX -A -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtuniq"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/en/xtsubstrHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "cutting substring as new field"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "attribute"
#define FLDC "an attribute from which substring is extracted (you cannot specify more than one attribute)"
#define FLDF ""

/*-R*/
#define RNGT "range list"
#define RNGC "specify the start and the last position of the specified attribute to be extracted"

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " This command extracts a substring from attribute(s) at -f from range -R, and have the option to store it as a new attribute or replaces the original attribute value in place. The following shows several ways of specifying the region by -R\
  (1) -R 1_4     : extract from the first to fourth characters\
  (2) -R MIN_5   : extract from the first to fifth characters\
  (3) -R 5_MAX   : extract from the fifth to the last characters\
  (4) -R 2       : extract the second character\
  (5) -R 1,5_MAX : extract the first character and from the fifth to the last characters Character position specified which is out of range will be ignored." 
/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  xtsubstr -fdate:year -R 1_4 -i dat.xt -o rsl.xt\n\
  xtsubstr -fdate:year_dairy -R 1_4,7_8 -i dat.xt -o rsl.xt\n\
  xtsubstr -fdate:year -R 1_4 -A -i dat.xt -o rsl.xt\n\
  xtsubstr -fdate:month_dairy -R 5_MAX -A -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtuniq"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
